/*
 *
 * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2000
 * http://www.biscom.net/~cade  <cade@biscom.net>  <cade@datamax.bg>
 *
 * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
 *
 */

#ifndef _VFUTOOLS_H_
#define _VFUTOOLS_H_

#include "vfu.h"

  void vfu_tool_classify();

  void vfu_tool_rename();
  
  void vfu_tool_seq_rename();

#endif //_VFUTOOLS_H_

 // eof vfutools.h
